==> pcileechfwgenerator-0.13.36.tar.gz: pcileechfwgenerator-0.13.36/src/tui/plugins/examples/network_device_plugin.py <==
"""
Network Device Plugin Example

Demonstrates plugin capabilities for network device analysis and optimization.
"""

import logging
from typing import Any, Dict, List, Optional

from ..plugin_base import (BuildHook, ConfigValidator, DeviceAnalyzer,
                           PCILeechPlugin)

# Set up logging
logger = logging.getLogger(__name__)


class NetworkDeviceAnalyzer:
    """Sample device analyzer for network devices."""

    def analyze_device(self, device_id: str, config_space: bytes) -> Dict[str, Any]:
        """
        Analyze a network device and return insights.

        Args:
            device_id: Device identifier
            config_space: Device configuration space data

        Returns:
            Dictionary containing analysis results
        """
        # In a real implementation, this would analyze the device's configuration space
        # to determine network capabilities, optimal settings, etc.
        results = {
            "device_type": "network",
            "capabilities": {
                "msi_support": True,
                "msix_support": config_space and len(config_space) > 0x80,
                "jumbo_frames": True,
                "advanced_filters": False,
            },
            "recommendations": [
                "Enable MSI-X for optimal interrupt handling",
                "Configure DMA buffer size to at least 2048 bytes",
            ],
            "compatibility_notes": [
                "May require firmware update for full PCIe Gen3 speed",
            ],
        }

        logger.info(f"Analyzed network device {device_id}")
        return results

    def get_name(self) -> str:
        """Get the name of the analyzer."""
        return "Network Device Analyzer"

    def get_description(self) -> str:
        """Get a description of the analyzer."""
        return "Analyzes network devices for optimal configuration"


class NetworkBuildHook:
    """Sample build hook for network device builds."""

    def pre_build(self, config: Dict[str, Any]) -> Dict[str, Any]:
        """
        Optimize configuration for network devices before build.

        Args:
            config: Build configuration

        Returns:
            Modified build configuration
        """
        # In a real implementation, this would adjust build parameters
        # based on the specific requirements for network devices

        # Only modify if it's a network device
        if config.get("device_type") == "network":
            # Apply network-specific optimizations
            config["enable_performance_counters"] = True
            config["feature_flags"]["jumbo_frame_support"] = True
            config["feature_flags"]["tcp_offload"] = True

            logger.info("Applied network device optimizations to build configuration")

        return config

    def post_build(self, build_result: Dict[str, Any]) -> Dict[str, Any]:
        """
        Process build results for network devices.

        Args:
            build_result: Build results

        Returns:
            Modified build results
        """
        # In a real implementation, this might add additional
        # network-specific metadata to the build results

        if build_result.get("config", {}).get("device_type") == "network":
            build_result["notes"] = build_result.get("notes", []) + [
                "Network device build completed with optimizations",
                "Check network throughput benchmarks for validation",
            ]

            logger.info("Added network-specific notes to build results")

        return build_result


class NetworkConfigValidator:
    """Sample configuration validator for network devices."""

    def validate_config(self, config: Dict[str, Any]) -> List[str]:
        """
        Validate a configuration for network devices.

        Args:
            config: Configuration to validate

        Returns:
            List of validation issues (empty if valid)
        """
        issues = []

        # Only validate if it's a network device
        if config.get("device_type") == "network":
            # Check for required network device settings
            if not config.get("enable_performance_counters", False):
                issues.append(
                    "Network devices should have performance counters enabled for monitoring"
                )

            # Check custom parameters
            custom_params = config.get("custom_parameters", {})
            if not custom_params.get("rx_buffer_size"):
                issues.append("Network devices should specify rx_buffer_size")

            if not custom_params.get("tx_buffer_size"):
                issues.append("Network devices should specify tx_buffer_size")

            logger.info(
                f"Validated network device configuration, found {len(issues)} issues"
            )

        return issues


class NetworkDevicePlugin(PCILeechPlugin):
    """
    Example plugin for network device support.

    This plugin provides specialized components for working with network devices:
    - Device analyzer for network capabilities
    - Build hooks for network optimizations
    - Configuration validation for network devices
    """

    def __init__(self):
        """Initialize the plugin components."""
        self._analyzer = NetworkDeviceAnalyzer()
        self._build_hook = NetworkBuildHook()
        self._config_validator = NetworkConfigValidator()
        self._initialized = False

    def get_name(self) -> str:
        """Get the plugin name."""
        return "Network Device Support"

    def get_version(self) -> str:
        """Get the plugin version."""
        return "1.0.0"

    def get_description(self) -> str:
        """Get the plugin description."""
        return "Provides specialized support for network device emulation"

    def get_device_analyzer(self) -> Optional[DeviceAnalyzer]:
        """Get the network device analyzer component."""
        return self._analyzer

    def get_build_hook(self) -> Optional[BuildHook]:
        """Get the network build hook component."""
        return self._build_hook

    def get_config_validator(self) -> Optional[ConfigValidator]:
        """Get the network configuration validator component."""
        return self._config_validator

    def initialize(self, app_context: Dict[str, Any]) -> bool:
        """Initialize the plugin with application context."""
        logger.info("Initializing Network Device Plugin")
        self._initialized = True
        return True

    def shutdown(self) -> None:
        """Clean up resources when the plugin is being unloaded."""
        logger.info("Shutting down Network Device Plugin")
        self._initialized = False

==> pcileechfwgenerator-0.13.38.tar.gz: pcileechfwgenerator-0.13.38/src/tui/plugins/examples/network_device_plugin.py <==
"""
Network Device Plugin Example

Demonstrates plugin capabilities for network device analysis and optimization.
"""

import logging
from typing import Any, Dict, List, Optional

from ..plugin_base import BuildHook, ConfigValidator, DeviceAnalyzer, PCILeechPlugin

# Set up logging
logger = logging.getLogger(__name__)


class NetworkDeviceAnalyzer:
    """Sample device analyzer for network devices."""

    def analyze_device(self, device_id: str, config_space: bytes) -> Dict[str, Any]:
        """
        Analyze a network device and return insights.

        Args:
            device_id: Device identifier
            config_space: Device configuration space data

        Returns:
            Dictionary containing analysis results
        """
        results = {
            "device_type": "network",
            "capabilities": {
                "msi_support": True,
                "msix_support": config_space and len(config_space) > 0x80,
                "jumbo_frames": True,
                "advanced_filters": False,
            },
            "recommendations": [
                "Enable MSI-X for optimal interrupt handling",
                "Configure DMA buffer size to at least 2048 bytes",
            ],
            "compatibility_notes": [
                "May require firmware update for full PCIe Gen3 speed",
            ],
        }

        logger.info(f"Analyzed network device {device_id}")
        return results

    def get_name(self) -> str:
        """Get the name of the analyzer."""
        return "Network Device Analyzer"

    def get_description(self) -> str:
        """Get a description of the analyzer."""
        return "Analyzes network devices for optimal configuration"


class NetworkBuildHook:
    """Sample build hook for network device builds."""

    def pre_build(self, config: Dict[str, Any]) -> Dict[str, Any]:
        """
        Optimize configuration for network devices before build.

        Args:
            config: Build configuration

        Returns:
            Modified build configuration
        """
        # Only modify if it's a network device
        if config.get("device_type") == "network":
            # Apply network-specific optimizations
            config["enable_performance_counters"] = True
            config["feature_flags"]["jumbo_frame_support"] = True
            config["feature_flags"]["tcp_offload"] = True

            logger.info("Applied network device optimizations to build configuration")

        return config

    def post_build(self, build_result: Dict[str, Any]) -> Dict[str, Any]:
        """
        Process build results for network devices.

        Args:
            build_result: Build results

        Returns:
            Modified build results
        """

        if build_result.get("config", {}).get("device_type") == "network":
            build_result["notes"] = build_result.get("notes", []) + [
                "Network device build completed with optimizations",
                "Check network throughput benchmarks for validation",
            ]

            logger.info("Added network-specific notes to build results")

        return build_result


class NetworkConfigValidator:
    """Sample configuration validator for network devices."""

    def validate_config(self, config: Dict[str, Any]) -> List[str]:
        """
        Validate a configuration for network devices.

        Args:
            config: Configuration to validate

        Returns:
            List of validation issues (empty if valid)
        """
        issues = []

        # Only validate if it's a network device
        if config.get("device_type") == "network":
            # Check for required network device settings
            if not config.get("enable_performance_counters", False):
                issues.append(
                    "Network devices should have performance counters enabled for monitoring"
                )

            # Check custom parameters
            custom_params = config.get("custom_parameters", {})
            if not custom_params.get("rx_buffer_size"):
                issues.append("Network devices should specify rx_buffer_size")

            if not custom_params.get("tx_buffer_size"):
                issues.append("Network devices should specify tx_buffer_size")

            logger.info(
                f"Validated network device configuration, found {len(issues)} issues"
            )

        return issues


class NetworkDevicePlugin(PCILeechPlugin):
    """
    Example plugin for network device support.

    This plugin provides specialized components for working with network devices:
    - Device analyzer for network capabilities
    - Build hooks for network optimizations
    - Configuration validation for network devices
    """

    def __init__(self):
        """Initialize the plugin components."""
        self._analyzer = NetworkDeviceAnalyzer()
        self._build_hook = NetworkBuildHook()
        self._config_validator = NetworkConfigValidator()
        self._initialized = False

    def get_name(self) -> str:
        """Get the plugin name."""
        return "Network Device Support"

    def get_version(self) -> str:
        """Get the plugin version."""
        return "1.0.0"

    def get_description(self) -> str:
        """Get the plugin description."""
        return "Provides specialized support for network device emulation"

    def get_device_analyzer(self) -> Optional[DeviceAnalyzer]:
        """Get the network device analyzer component."""
        return self._analyzer

    def get_build_hook(self) -> Optional[BuildHook]:
        """Get the network build hook component."""
        return self._build_hook

    def get_config_validator(self) -> Optional[ConfigValidator]:
        """Get the network configuration validator component."""
        return self._config_validator

    def initialize(self, app_context: Dict[str, Any]) -> bool:
        """Initialize the plugin with application context."""
        logger.info("Initializing Network Device Plugin")
        self._initialized = True
        return True

    def shutdown(self) -> None:
        """Clean up resources when the plugin is being unloaded."""
        logger.info("Shutting down Network Device Plugin")
        self._initialized = False
